You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by kr...@apache.org on 2007/05/04 16:48:49 UTC

svn commit: r535270 - /db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogToFile.java

Author: kristwaa
Date: Fri May  4 07:48:49 2007
New Revision: 535270

URL: http://svn.apache.org/viewvc?view=rev&rev=535270
Log:
DERBY-2020: Change of mode for opening log files from "rws" to "rwd".

Patch contributed by Olav Sandstå.

Modified:
    db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogToFile.java

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogToFile.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogToFile.java?view=diff&rev=535270&r1=535269&r2=535270
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogToFile.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogToFile.java Fri May  4 07:48:49 2007
@@ -912,7 +912,7 @@
 						lastFlush   = endPosition;
 						
 						//if write sync is true , prellocate the log file
 						//and reopen the file in rws mode.
 						if(isWriteSynced)
 						{
 							//extend the file by wring zeros to it
@@ -3112,7 +3112,7 @@
 					lastFlush = firstLog.getFilePointer();
 
                     //if write sync is true , prellocate the log file
                     //and reopen the file in rws mode.
                     if(isWriteSynced)
                     {
                         //extend the file by wring zeros to it
@@ -5028,7 +5028,7 @@
             }
         }
 
-		StorageRandomAccessFile log = privRandomAccessFile(logFile, "rws");
+		StorageRandomAccessFile log = privRandomAccessFile(logFile, "rwd");
 		return log ;
 	}
@@ -912,7 +912,7 @@
 						
 						//if write sync is true , prellocate the log file
-						//and reopen the file in rws mode.
+						//and reopen the file in rwd mode.
 						if(isWriteSynced)
 						{
@@ -3112,7 +3112,7 @@
 
                     //if write sync is true , prellocate the log file
-                    //and reopen the file in rws mode.
+                    //and reopen the file in rwd mode.
                     if(isWriteSynced)
                     {